#
# spec file for package WSL-DistroLauncher
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           WSL-DistroLauncher
# no official release yet
Version:        0.0.1+git20200918.2ed9a93
Release:        lp156.3.4
Summary:        Windows Subsystem for Linux distro launcher
License:        MIT
URL:            https://github.com/openSUSE/WSL-DistroLauncher

Source:         WSL-DistroLauncher-%{version}.tar.xz
Source1:        icon.ico

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  mingw64-cross-binutils
BuildRequires:  mingw64-cross-gcc-c++
BuildRequires:  mingw64-filesystem

# XXX: that's a bit nasty. Launcher should probably be made run
# time configurable when packing the appx
%if 0%{?is_opensuse}
BuildRequires:  openSUSE-release
%else
BuildRequires:  sles-release
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%_mingw64_package_header_debug
BuildArch:      noarch

%description
Windows application shipped within the WSL applications in the
Windows Store. This application is initializing and launching
the distribution.

%_mingw64_debug_package

%prep
%autosetup -p1

cp %{S:1} DistroLauncher/icon.ico

%build
autoreconf -fi
if [ -e /usr/lib/os-release ]; then
	source /usr/lib/os-release
else
	source /etc/os-release
fi

# PRETTY_NAME is embedded in WSL launcher executable Windows resource metadata.
# Modify PRETTY_NAME for allowed characters and stable name dropping SLE prerelease.
# During SLE prerelease phases, parens around RC etc. in PRETTY_NAME
# will not not be properly escaped if passed to mingw configure step.
#
# Reuse bash substitution pattern from obs-service-kiwi_metainfo_helper.
#
# PRETTY_NAME:                     openSUSE Leap 15.3
# PRETTY_NAME_BEFORE_PAREN:        openSUSE Leap 15.3
# PRETTY_NAME_BEFORE_PAREN_DASHED: openSUSE-Leap-15.3
#
# PRETTY_NAME:                     SUSE Linux Enterprise Server 15 SP3 (Snapshot16)
# PRETTY_NAME_BEFORE_PAREN:        SUSE Linux Enterprise Server 15 SP3
# PRETTY_NAME_BEFORE_PAREN_DASHED: SUSE-Linux-Enterprise-Server-15-SP3
#
# Special case for SLE release labels e.g. RC1. Keep only up to (space) open paren.
# Provides a stable project name for third-party integrations e.g. app store submissions
# 20230630, smb - Removing " Server" from PRETTY_NAME so distro isn't registered
#  with it in the name.
PRETTY_NAME="${PRETTY_NAME// Server/}"
PRETTY_NAME_BEFORE_PAREN="${PRETTY_NAME// (*/}"

# Attribute distro-id must not contain spaces, replace with dash
PRETTY_NAME_BEFORE_PAREN_DASHED="${PRETTY_NAME_BEFORE_PAREN//[^[:alnum:].]/-}"

%{_mingw64_configure} --with-windmc=%{_mingw64_windmc} \
                      --with-windres=%{_mingw64_windres} \
                      --with-distro-id="$PRETTY_NAME_BEFORE_PAREN_DASHED" \
                      --with-distro-name="$PRETTY_NAME_BEFORE_PAREN" \
                      --with-distro-icon="icon.ico"
make %{?_smp_mflags}

%install
%make_install

%files
%doc README.md
%license COPYING
%{_mingw64_bindir}/DistroLauncher.exe

%changelog
* Tue Aug 22 2023 Scott Bradnick <scott.bradnick@suse.com>
- Microsoft prefers Name and distro id to be the same for usage with wsl.exe
  * Removing " Server" from PRETTY_NAME so distro isn't registered
    with it in the name
  * This way both `wsl --install SUSE-Linux-Enterprise-15-SP5` and
    `wsl -d SUSE-Linux-Enterprise-15-SP5` work vs. the second
    iteration needing "Server" in the name
* Fri Jun 25 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Prepare distro-id and distro_name configure variables using bash
  subst method from obs-service-kiwi_metainfo_helper and wsl-appx.
  * PRETTY_NAME_BEFORE_PAREN
  * PRETTY_NAME_BEFORE_PAREN_DASHED
* Fri Jun 25 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.0.1+git20200918.2ed9a93:
  * Run yast2-firstboot instead of useradd
  * refactor QueryUid to be reusable
  * SUSE adjustments
  * replace wscanf_s, seems not defined in mingw
  * Cross compiling the launcher
  * Add Visual Studio 2019 Community support (#74)
  * Update platformtoolset to use v142 (#60)
  * Update README step 5 to set TargetName instead of ProjectName (#72)
  * Update DistroLauncher/DistroLauncher.cpp to better check wsl.exe exit code
  * Added prompt for input when wsl.exe fails to launch Linux process
- Drop patch files now obtained from openSUSE git repository
  * drop 0001-Cross-compiling-the-launcher.patch
  * drop 0002-replace-wscanf_s-seems-not-defined-in-mingw.patch
  * drop 0003-SUSE-adjustments.patch
  * drop 0004-refactor-QueryUid-to-be-reusable.patch
  * drop 0005-Run-yast2-firstboot-instead-of-useradd.patch
* Thu Apr  8 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- During prerelease phases, parens around RC etc. in PRETTY_NAME
  are not properly escaped if passed to mingw configure step.
  * PRETTY_NAME keep only alphanum+space when passing as distro-id
* Fri Apr 10 2020 Scott Reeves <sreeves@suse.com>
- Update git snapshot - Better error handling on WSL2 startup
* Tue Oct 15 2019 Ludwig Nussel <lnussel@suse.de>
- squash patches
- run YaST firstboot wizard to configure WSL
* Fri Oct  4 2019 Ludwig Nussel <lnussel@suse.de>
- fix username input 0001-Fix-user-name-input.patch
* Fri Oct  4 2019 Ludwig Nussel <lnussel@suse.de>
- use config.h actually to set proper distro (0001-actually-use-config.h-settings.patch, boo#1133525)
- remove usermod (0001-Don-t-add-groups-to-user.-Not-needed-on-SUSE-distros.patch, boo#1148983)
* Wed Oct  2 2019 Ludwig Nussel <lnussel@suse.de>
- avoid %%make_build, not available on sle12 yet
* Tue Oct  1 2019 Ludwig Nussel <lnussel@suse.de>
- fix 0005-adduser-vs-useradd.patch (boo#1150663)
* Mon Sep  9 2019 Rich Williams <riwilliams@suse.com>
- Added patch (0005-adduser-vs-useradd.patch) to change default
  MS (Ubuntu-centric) user management commands to SUSE-centric
  commands.
* Thu Aug 29 2019 Dan Čermák <dcermak@suse.com>
- Cleanup spec file:
  * use tar_scm service to download source
  * fix the line endings in %%prep
- Rebase patches:
  Added:
  * 0001-Cross-compiling-the-launcher.patch (was mingw.patch, wslapi.patch and
    0001-Use-mconsole-instead-of-mwindows.patch)
  * 0002-Fix-race-during-build.patch (was 0001-Fix-race-during-build.patch)
  * 0003-Don-t-use-any-of-the-garbage-_s-functions.patch (was
    0002-Don-t-use-any-of-the-garbage-_s-functions.patch)
  * 0004-Initialize-the-project-as-foreign.patch
  Dropped:
  * 0001-Fix-race-during-build.patch (rebased)
  * 0001-Use-mconsole-instead-of-mwindows.patch (incorporated into
    0001-Cross-compiling-the-launcher.patch)
  * 0002-Don-t-use-any-of-the-garbage-_s-functions.patch (rebased)
  * SUSE-distros.patch (dropped completely)
  * mingw.patch (rebased as 0001-Cross-compiling-the-launcher.patch)
  * wslapi.patch (incorporated into 0001-Cross-compiling-the-launcher.patch)
* Fri Aug 23 2019 Rich Williams <riwilliams@suse.com>
- Code now rebased from upstream (Microsoft) source.
- Several "patches-to-patches-that-patched-a-patch" are consolidated:
  - `0001-Fix-race-during-build.patch`
  - `0001-Use-mconsole-instead-of-mwindows.patch`
  - `mingw.patch` (only patches to `*/Makefile.*`)
  ...are consolidated (w/ preserved headers) into `makefiles.patch`.
- C++17 standard now in use.
- Code for `SUSEConnect` has been removed temporarily:
  - Several upstream where `SUSEConnect` was inserted were deleted.
  - `SUSEConnect` upon WSL init didn't work correctly anyway.
- A better suited substitute for `wscanf_s()` was found in the
  mingw64 headers: `wscanf_s()` --> `swscanf_s()`
- Added shell script to handle file encoding and line ends in
  the upstream files.
* Thu Oct 12 2017 cbosdonnat@suse.com
- Initial package
